# Json Utilities
This package has two small functions, `get_json` `save_json`,


`get_json(filePath: str) -> dict`

`save_json(data: dict, filePath: str) -> bool` will save whatever `data` contains into file at `filePath`, with default indentation of 4, returns True if the operation was successful.




